BatchEventDto class final

Inheritance

Constructors

BatchEventDto({required int seq, required int tsMicros, required String sessionId, required List<EntityUpdatedEventDto> entityUpdates, required List<EntityFiredEventDto> entityFirings, required List<SystemFiredEventDto> systemFirings, required int droppedFirings})
const

Properties

droppedFirings int
final
entityFirings List<EntityFiredEventDto>
final
entityUpdates List<EntityUpdatedEventDto>
final
hashCode int
The hash code for this object.
no setterinherited
kind String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seq int
finalinherited
sessionId String
finalinherited
systemFirings List<SystemFiredEventDto>
final
tsMicros int
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
payload() Map<String, Object?>
override
toJson() Map<String, Object?>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited