EntityFiredEventDto class final

Constructors

EntityFiredEventDto({required String entityId, required JsonValueDto? payloadValue, required int firedAtMicros, required int fireCount})
const
EntityFiredEventDto.fromMap(Map<String, Object?> json)
factory

Properties

entityId String
final
fireCount int
final
firedAtMicros int
final
hashCode int
The hash code for this object.
no setterinherited
payloadValue JsonValueDto?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited