EntityUpdatedEventDto class final

Constructors

EntityUpdatedEventDto({required String entityId, required JsonValueDto? value, required JsonValueDto? previous, required int updatedAtMicros, required int updateCount})
const
EntityUpdatedEventDto.fromMap(Map<String, Object?> json)
factory

Properties

entityId String
final
hashCode int
The hash code for this object.
no setterinherited
previous JsonValueDto?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updateCount int
final
updatedAtMicros int
final
value JsonValueDto?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited