EventDto class sealed

Sealed union of every push event.

Implementers

Constructors

EventDto.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
kind String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seq int
final
sessionId String
final
tsMicros int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
payload() Map<String, Object?>
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited