LogDto class final

Constructors

LogDto({required String id, required LogLevelDto level, required int tsMicros, required String message, String? orchestrationId, String? systemId, List<String> entityRefs = const [], String? stack})
const
LogDto.fromJson(Map<String, Object?> json)
factory

Properties

entityRefs List<String>
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
level LogLevelDto
final
message String
final
orchestrationId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stack String?
final
systemId String?
final
tsMicros int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited