LogEmittedEventDto class final

Inheritance

Constructors

LogEmittedEventDto({required int seq, required int tsMicros, required String sessionId, required LogDto log})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
kind String
no setteroverride
log LogDto
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seq int
finalinherited
sessionId String
finalinherited
tsMicros int
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
payload() Map<String, Object?>
override
toJson() Map<String, Object?>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited