OrchestrationDto class final

Constructors

OrchestrationDto({required String id, required String name, required String orchestratorId, List<EntityDto> entities = const [], List<SystemDto> systems = const []})
const
OrchestrationDto.fromJson(Map<String, Object?> json)
factory

Properties

entities List<EntityDto>
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
name String
final
orchestratorId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
systems List<SystemDto>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited