OrchestratorDto class final
Constructors
-
OrchestratorDto({required String id, required String name, required bool isActive, List<
OrchestrationDto> orchestrations = const []}) -
const
-
OrchestratorDto.fromJson(Map<
String, Object?> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- isActive → bool
-
final
- name → String
-
final
-
orchestrations
→ List<
OrchestrationDto> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited