SubscribeResponseDto class final
Constructors
-
SubscribeResponseDto({required int protocolVersion, required String sessionId, required int serverStartedAtMicros, required int seq, required List<
OrchestratorDto> orchestrators, required List<LogDto> recentLogs}) -
const
-
SubscribeResponseDto.fromJson(Map<
String, Object?> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
orchestrators
→ List<
OrchestratorDto> -
final
- protocolVersion → int
-
final
-
recentLogs
→ List<
LogDto> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seq → int
-
final
- serverStartedAtMicros → int
-
final
- sessionId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited