SystemDto class final
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
-
interactsWithEntityIds
→ List<
String> -
final
- kind → SystemKindDto
-
final
- name → String
-
final
- orchestrationId → String
-
final
-
reactsToEntityIds
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited