TopologyEventDto class final

Inheritance

Constructors

TopologyEventDto({required int seq, required int tsMicros, required String sessionId, required TopologyChangeKind change, OrchestratorDto? orchestrator, OrchestrationDto? orchestration, EntityDto? entity, SystemDto? system, String? removedId})
const
TopologyEventDto.fromJsonInner(Map<String, Object?> json, {required int seq, required int tsMicros, required String sessionId})
factory

Properties

change TopologyChangeKind
final
entity EntityDto?
final
hashCode int
The hash code for this object.
no setterinherited
kind String
no setteroverride
orchestration OrchestrationDto?
final
orchestrator OrchestratorDto?
final
removedId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seq int
finalinherited
sessionId String
finalinherited
system SystemDto?
final
tsMicros int
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
payload() Map<String, Object?>
override
toJson() Map<String, Object?>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited