reactsTo property

Set<Type> get reactsTo

The set of entity types that this system reacts to.

This set should be overridden in subclasses to specify the types of entities that this system reacts to.

This is used to optimize the system's reaction by filtering entities that are relevant to the system and avoid unnecessary processing.

This is also used for debugging purposes to understand which entities are being processed by the system.

Implementation

Set<Type> get reactsTo;