EntityDto class final
Constructors
- EntityDto({required String id, required String name, required EntityKindDto kind, required String typeName, required String orchestrationId, JsonValueDto? value, JsonValueDto? previous, int? updatedAtMicros})
-
const
-
EntityDto.fromJson(Map<
String, Object?> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- kind → EntityKindDto
-
final
- name → String
-
final
- orchestrationId → String
-
final
- previous → JsonValueDto?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- typeName → String
-
final
- updatedAtMicros → int?
-
final
- value → JsonValueDto?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited