SystemFiredEventDto class final
Constructors
- SystemFiredEventDto({required String systemId, required String? triggerEntityId, required int durationMicros, required bool succeeded, required int firedAtMicros})
-
const
-
SystemFiredEventDto.fromMap(Map<
String, Object?> json) -
factory
Properties
- durationMicros → int
-
final
- firedAtMicros → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- succeeded → bool
-
final
- systemId → String
-
final
- triggerEntityId → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited