orchestra library
Classes
- CleanupSystem
- Base class for cleanup systems.
- CleanupSystemDefinition
-
Component<
TValue> - Represents a component that hold data and can be updated and will notify listeners when their value changes.
-
ComponentDefinition<
T> - Composer
-
DataEvent<
TData> - Data events are events that can be triggered with associated data to notify listeners.
-
DataEventDefinition<
T> -
Dependency<
TValue> - Represents a dependency that hold a value and can be injected into features or systems.
-
DependencyDefinition<
T> - Element
- Entity
- Base entity.
- EntityDefinition
- EntityListener
- Interface for listening to changes in entities.
- Event
- Represents an event that can be triggered to notify listeners.
- EventDefinition
- ExecuteSystem
- Base class for execute systems.
- ExecuteSystemDefinition
- InitializeSystem
- Base class for initialize systems.
- InitializeSystemDefinition
- ListenableEntity
- Represents a listenable entity that can notify listeners of changes.
- ListenableEntityDefinition
- Orchestration
- Orchestrations can contain entities and systems, and they provide a way to organize and manage different parts of the architecture.
- OrchestrationDefinition
- Orchestrator
- Base class for managing orchestrations.
- ReactiveSystem
- Base class for reactive systems.
- ReactiveSystemDefinition
- System
- Base class for systems.
- TeardownSystem
- Base class for teardown systems.
- TeardownSystemDefinition