CleanupSystem class abstract
Base class for cleanup systems.
Cleanup systems are used to perform cleanup tasks.
The cleanup method should be overridden in subclasses to perform the actual cleanup logic.
The cleanup method is called after all ExecuteSystems have been executed and before the next frame is rendered.
Constructors
Properties
- cleansIf → bool
-
Whether the system should be executed or not.
no setter
-
entities
↔ Map<
Type, Entity> -
Cached entities that this system interacts with.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → String
-
Unique identifier for this system.
no setterinherited
- inspectorId ↔ String?
-
Stable id for the inspector wire protocol; assigned at registration time.
getter/setter pairinherited
-
interactsWith
→ Set<
Type> -
Set of types that this system interacts with.
no setterinherited
- isAttached → bool
-
Indicates whether this system is active.
no setterinherited
- orchestration ↔ Orchestration?
-
The parent orchestration of this system.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
attach(
Orchestration orchestration) → void -
Attaches this system to an orchestration.
inherited
-
cleanup(
) → void - Cleanup logic for the system.
-
get<
TEntity extends Entity> () → TEntity -
Gets an entity of type
TEntityinherited -
log(
String message, {LogLevel level = LogLevel.info}) → void -
Logs a message to the logging system.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited