InitializeSystem class abstract
Base class for initialize systems.
Initialize systems are used to perform setup tasks.
The initialize method should be overridden in subclasses to perform the actual initialization logic.
The initialize method is called once after the first frame is rendered and before any other systems are executed.
Constructors
Properties
-
entities
↔ Map<
Type, Entity> -
Cached entities that this system interacts with.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → String
-
Unique identifier for this system.
no setterinherited
- inspectorId ↔ String?
-
Stable id for the inspector wire protocol; assigned at registration time.
getter/setter pairinherited
-
interactsWith
→ Set<
Type> -
Set of types that this system interacts with.
no setterinherited
- isAttached → bool
-
Indicates whether this system is active.
no setterinherited
- orchestration ↔ Orchestration?
-
The parent orchestration of this system.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
attach(
Orchestration orchestration) → void -
Attaches this system to an orchestration.
inherited
-
get<
TEntity extends Entity> () → TEntity -
Gets an entity of type
TEntityinherited -
initialize(
) → void - Initialize logic for the system.
-
log(
String message, {LogLevel level = LogLevel.info}) → void -
Logs a message to the logging system.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited