ReactiveSystem class abstract
Base class for reactive systems.
Reactive systems are used to react to changes in entities.
The react method should be overridden in subclasses to perform the actual reaction logic.
- Inheritance
- Implemented types
Constructors
Properties
-
entities
↔ Map<
Type, Entity> -
Cached entities that this system interacts with.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → String
-
Unique identifier for this system.
no setterinherited
- inspectorId ↔ String?
-
Stable id for the inspector wire protocol; assigned at registration time.
getter/setter pairinherited
-
interactsWith
→ Set<
Type> -
Set of types that this system interacts with.
no setterinherited
- isActive → bool
-
no setter
- isAttached → bool
-
Indicates whether this system is active.
no setterinherited
- orchestration ↔ Orchestration?
-
The parent orchestration of this system.
getter/setter pairinherited
- reactsIf → bool
-
Whether the system reacts to changes in entities.
no setter
-
reactsTo
→ Set<
Type> -
The set of entity types that this system reacts to.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
activate(
) → void - Activates this system by adding listeners to the entities it reacts to.
-
attach(
Orchestration orchestration) → void -
Attaches this system to an orchestration.
inherited
-
deactivate(
) → void - Deactivates this system by removing listeners from the entities it reacts to.
-
get<
TEntity extends Entity> () → TEntity -
Gets an entity of type
TEntityinherited -
log(
String message, {LogLevel level = LogLevel.info}) → void -
Logs a message to the logging system.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onEntityChanged(
Entity entity) → void -
Called when an entity changes.
override
-
react(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited